# LabEquipment
Library of classes for interfacing with common lab equipment in Python.

# Required Libraries
- NumPY
- Pandas
- pyVISA
- EasySCPI
- pythonnet

TLB6700 specifically requires:
- .NET to be installed, see https://dotnet.microsoft.com/en-us/download
- Newport USB drivers installed, see https://www.newport.com/software-and-drivers, https://download.newport.com/#/Software/Newport_USB_Driver/
- UsbDllWrap.dll in a path location, contains NewPort module
